/*
 *  ThemeEndianness.h
 *  ShapeShifter
 *
 *  Created by Jason Harris on 2/11/06.
 *  Copyright 2006 Geekspiff. All rights reserved.
 *
 */

#include <CoreFoundation/CoreFoundation.h>

#ifndef __THEMEENDIANNESS__
#define __THEMEENDIANNESS__

#ifdef __cplusplus
extern "C" {
#endif
    
/*
 * ThemeDataFormat
 *
 * kThemeDataFormatUnknown      The format of the data could not be determined
 * kThemeDataBigEndian          All data within the file is stored in big-endian format
 * kThemeDataLittleEndian       All data within the file is stored in little-endian format
 */
enum {
    kThemeDataFormatUnknown         = 0, 
    kThemeDataBigEndian             = 1,
    kThemeDataLittleEndian          = 2,
};
typedef UInt32 ThemeDataFormat;


/*
 * Errors
 *
 * kThemeDataNoError            No errors occurred
 * kThemeDataBadParameter       A parameter passed to a function was an unexpected value
 * kThemeDataBadFile            The resource file could not be read
 * kThemeDataBadResource        The resource file contained an unreadable resource
 * kThemeDataUnexpectedError    An unexpected error prevented the operation from concluding
 */
enum {
    kThemeDataNoError               = 0, 
    kThemeDataBadParameter          = 1, 
    kThemeDataBadFile               = 2, 
    kThemeDataBadResource           = 3,
    kThemeDataUnexpectedError       = 4,
};
typedef UInt32 ThemeDataError;


/*
 * Determines the data format for inPath and returns in in outFormat.  The output format will be 
 * either kThemeDataFormatUnknown or kThemeDataLittleEndian.  If it is kThemeDataFormatUnknown, 
 * you will need to use ThemeDataFormatForResourceFile to determine the format.
 * 
 * Returns kThemeDataBadParameter if either input parameter is NULL.  Returns kThemeDataBadFile
 * if there are problems resolving inPath.
 */
ThemeDataError ThemeDataFormatForPath(CFStringRef inPath, ThemeDataFormat *outFormat);


/* 
 * Determines the data for the open resource file with inRefNum and returns in in outFormat.  If the 
 * resource file contains an 'Endn' resource with ID 128, but the resource is in an unexpected format, 
 * returns kThemeDataBadResource.
 */
ThemeDataError ThemeDataFormatForResourceFile(SInt16 inRefNum, ThemeDataFormat *outFormat);


/*
 * Tags the resource file with inRefNum to indicate that its resources are stored with inFormat.  
 * This does not modify any resources other than 'Endn' ID 128, which is created or modified as needed.
 */
ThemeDataError SetThemeDataFormatForResourceFile(SInt16 inRefNum, ThemeDataFormat inFormat);

#ifdef __cplusplus
}
#endif
    
#endif // __THEMEENDIANNESS__
